@@ -159,7 +159,7 @@ def generate_example_input(
                 else:
                     comment = "optional"
         else:
-            example = yaml.comments.CommentedSeq()
+            example = CommentedSeq()
             for index, entry in enumerate(inptype):
                 value, e_comment = generate_example_input(entry, default)
                 example.append(value)
@@ -554,13 +554,11 @@ def find_deps(
 
 
 def print_pack(
-    document_loader,  # type: Loader
-    processobj,  # type: CommentedMap
+    loadingContext,  # type: LoadingContext
     uri,  # type: str
-    metadata,  # type: Dict[str, Any]
 ):  # type: (...) -> str
     """Return a CWL serialization of the CWL document in JSON."""
-    packed = pack(document_loader, processobj, uri, metadata)
+    packed = pack(loadingContext, uri)
     if len(packed["$graph"]) > 1:
         return json_dumps(packed, indent=4)
     return json_dumps(packed["$graph"][0], indent=4)
@@ -610,10 +608,17 @@ def setup_schema(
         custom_schema_callback()
     elif args.enable_ext:
         res = pkg_resources.resource_stream(__name__, "extensions.yml")
-        use_custom_schema("v1.0", "http://commonwl.org/cwltool", res.read())
+        ext10 = res.read()
+        res = pkg_resources.resource_stream(__name__, "extensions-v1.1.yml")
+        ext11 = res.read()
+        use_custom_schema("v1.0", "http://commonwl.org/cwltool", ext10)
+        use_custom_schema("v1.1", "http://commonwl.org/cwltool", ext11)
+        use_custom_schema("v1.2.0-dev2", "http://commonwl.org/cwltool", ext11)
         res.close()
     else:
         use_standard_schema("v1.0")
+        use_standard_schema("v1.1")
+        use_standard_schema("v1.2.0-dev2")
 
 
 def setup_provenance(
@@ -917,15 +922,13 @@ def main(
             processobj, metadata = loadingContext.loader.resolve_ref(uri)
             processobj = cast(CommentedMap, processobj)
             if args.pack:
-                stdout.write(
-                    print_pack(loadingContext.loader, processobj, uri, metadata)
-                )
+                stdout.write(print_pack(loadingContext, uri))
                 return 0
 
             if args.provenance and runtimeContext.research_obj:
                 # Can't really be combined with args.pack at same time
                 runtimeContext.research_obj.packed_workflow(
-                    print_pack(loadingContext.loader, processobj, uri, metadata)
+                    print_pack(loadingContext, uri)
                 )
 
             if args.print_pre:
