@@ -3,6 +3,7 @@ import os
 import tempfile
 from functools import partial
 from io import StringIO
+from tempfile import NamedTemporaryFile
 
 import pytest
 
@@ -21,18 +22,11 @@ from .util import get_data, needs_docker
 
 def test_pack():
     loadingContext, workflowobj, uri = fetch_document(get_data("tests/wf/revsort.cwl"))
-    loadingContext.do_update = False
-    loadingContext, uri = resolve_and_validate_document(
-        loadingContext, workflowobj, uri
-    )
-    processobj = loadingContext.loader.resolve_ref(uri)[0]
 
     with open(get_data("tests/wf/expect_packed.cwl")) as packed_file:
         expect_packed = yaml.safe_load(packed_file)
 
-    packed = cwltool.pack.pack(
-        loadingContext.loader, processobj, uri, loadingContext.metadata
-    )
+    packed = cwltool.pack.pack(loadingContext, uri)
     adjustFileObjs(
         packed, partial(make_relative, os.path.abspath(get_data("tests/wf")))
     )
@@ -59,9 +53,7 @@ def test_pack_input_named_name():
     with open(get_data("tests/wf/expect_trick_packed.cwl")) as packed_file:
         expect_packed = yaml.round_trip_load(packed_file)
 
-    packed = cwltool.pack.pack(
-        loadingContext.loader, processobj, uri, loadingContext.metadata
-    )
+    packed = cwltool.pack.pack(loadingContext, uri)
     adjustFileObjs(
         packed, partial(make_relative, os.path.abspath(get_data("tests/wf")))
     )
@@ -85,12 +77,26 @@ def test_pack_single_tool():
     )
     processobj = loadingContext.loader.resolve_ref(uri)[0]
 
-    packed = cwltool.pack.pack(
-        loadingContext.loader, processobj, uri, loadingContext.metadata
-    )
+    packed = cwltool.pack.pack(loadingContext, uri)
     assert "$schemas" in packed
 
 
+def test_pack_fragment():
+    with open(get_data("tests/wf/scatter2_subwf.cwl")) as packed_file:
+        expect_packed = yaml.safe_load(packed_file)
+
+    loadingContext, workflowobj, uri = fetch_document(get_data("tests/wf/scatter2.cwl"))
+    packed = cwltool.pack.pack(loadingContext, uri + "#scatterstep/mysub")
+    adjustFileObjs(
+        packed, partial(make_relative, os.path.abspath(get_data("tests/wf")))
+    )
+    adjustDirObjs(packed, partial(make_relative, os.path.abspath(get_data("tests/wf"))))
+
+    assert json.dumps(packed, sort_keys=True, indent=2) == json.dumps(
+        expect_packed, sort_keys=True, indent=2
+    )
+
+
 def test_pack_rewrites():
     rewrites = {}
 
@@ -104,11 +110,7 @@ def test_pack_rewrites():
     processobj = loadingContext.loader.resolve_ref(uri)[0]
 
     cwltool.pack.pack(
-        loadingContext.loader,
-        processobj,
-        uri,
-        loadingContext.metadata,
-        rewrite_out=rewrites,
+        loadingContext, uri, rewrite_out=rewrites,
     )
 
     assert len(rewrites) == 6
@@ -132,9 +134,7 @@ def test_pack_missing_cwlVersion(cwl_path):
     processobj = loadingContext.loader.resolve_ref(uri)[0]
 
     # generate pack output dict
-    packed = json.loads(
-        print_pack(loadingContext.loader, processobj, uri, loadingContext.metadata)
-    )
+    packed = json.loads(print_pack(loadingContext, uri))
 
     assert packed["cwlVersion"] == "v1.0"
 
@@ -158,19 +158,29 @@ def _pack_idempotently(document):
     processobj = loadingContext.loader.resolve_ref(uri)[0]
 
     # generate pack output dict
-    packed = json.loads(
-        print_pack(loadingContext.loader, processobj, uri, loadingContext.metadata)
-    )
+    packed_text = print_pack(loadingContext, uri)
+    packed = json.loads(packed_text)
 
-    loadingContext, workflowobj, uri2 = fetch_document(packed)
-    loadingContext.do_update = False
-    loadingContext, uri2 = resolve_and_validate_document(
-        loadingContext, workflowobj, uri
-    )
-    processobj = loadingContext.loader.resolve_ref(uri2)[0]
-    double_packed = json.loads(
-        print_pack(loadingContext.loader, processobj, uri2, loadingContext.metadata)
-    )
+    tmp = NamedTemporaryFile(mode="w", delete=False)
+    try:
+        tmp.write(packed_text)
+        tmp.flush()
+        tmp.close()
+
+        loadingContext, workflowobj, uri2 = fetch_document(tmp.name)
+        loadingContext.do_update = False
+        loadingContext, uri2 = resolve_and_validate_document(
+            loadingContext, workflowobj, uri2
+        )
+        processobj = loadingContext.loader.resolve_ref(uri2)[0]
+
+        # generate pack output dict
+        packed_text = print_pack(loadingContext, uri2)
+        double_packed = json.loads(packed_text)
+    finally:
+        os.remove(tmp.name)
+
+    assert uri != uri2
     assert packed == double_packed
 
 
@@ -191,9 +201,7 @@ def test_packed_workflow_execution(wf_path, job_path, namespaced, tmpdir):
         loadingContext, workflowobj, uri
     )
     processobj = loadingContext.loader.resolve_ref(uri)[0]
-    packed = json.loads(
-        print_pack(loadingContext.loader, processobj, uri, loadingContext.metadata)
-    )
+    packed = json.loads(print_pack(loadingContext, uri))
 
     assert not namespaced or "$namespaces" in packed
 
